summaryrefslogtreecommitdiff
path: root/png.c
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-01-30 15:34:44 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-01-30 15:37:46 -0600
commit0cbe85bcfdfc675a11e992434e6e76b8740e2697 (patch)
treec659d68770db5eeebf1c94b57cc89390655e5588 /png.c
parent39126d5707cacc9dce17c0b74417bf2643ae7c42 (diff)
downloadlibpng-0cbe85bcfdfc675a11e992434e6e76b8740e2697.tar.gz
[libpng12] Imported from libpng-1.2.51rc02.tarv1.2.51rc02
Diffstat (limited to 'png.c')
-rw-r--r--png.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/png.c b/png.c
index b4191f0ff..2b538e46b 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
* Last changed in libpng 1.2.51 [January 28, 2014]
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -17,7 +17,7 @@
#include "png.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_2_51rc01 Your_png_h_is_not_version_1_2_51rc01;
+typedef version_1_2_51rc02 Your_png_h_is_not_version_1_2_51rc02;
/* Version information for C files. This had better match the version
* string defined in png.h.
@@ -724,13 +724,13 @@ png_get_copyright(png_structp png_ptr)
#else
#ifdef __STDC__
return ((png_charp) PNG_STRING_NEWLINE \
- "libpng version 1.2.51rc01 - January 28, 2014" PNG_STRING_NEWLINE \
+ "libpng version 1.2.51rc02 - January 30, 2014" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2014 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE);
#else
- return ((png_charp) "libpng version 1.2.51rc01 - January 28, 2014\
+ return ((png_charp) "libpng version 1.2.51rc02 - January 30, 2014\
Copyright (c) 1998-2014 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
- * Last changed in libpng 1.2.51 [January 28, 2014]
+ * Last changed in libpng 1.2.51 [January 30, 2014]
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)